# Function 7 Round a number of zones. Arguments on stack: _cvt_first_zone, zones_count_

Assembly |  | Stack
--- | --- | ---
PUSHW[ ] | 1 value pushed
7 | function index
FDEF[ ] | FunctionDefinition
PUSHW[ ] | 1 value pushed
6 | function index | cvt_first_zone zones_count 6
LOOPCALL[ ] | LoopAndCallFunction 6 | cvt_first_zone+2*zones_count
ENDF[ ] | EndFunctionDefinition

Returns on stack: The CVT index of the last zone + 2